#include <cassert>
#ifdef DEBUG
    #include <iostream>
#endif
#include <climits>
#include <fstream>
#include <string>

using namespace std;

/* The approach and the general structure of the code have been taken from the
   solution of the Hanoi problem proposed in the September 3rd, 2012 exam. */

const int MAX_N = 1000;
int numberOfDisks;
int currentPosition[MAX_N + 1];
int numDisks, numPegs;
long int numOfMoves;
bool occupiedPegs[MAX_N + 1];

void moveTower(int firstDisk, int lastDisk, int fromPeg, int toPeg) {
    /* If the tower is of height 1, move the disk and increment the number of
       moves. If not, move it according to the strategy. */
    if (firstDisk == lastDisk) {
        currentPosition[lastDisk] = toPeg;
        #ifdef DEBUG
            std::cout << "Muovo il disco " << lastDiskToMove << " dal piolo "
                      << fromPeg << " al piolo " << toPeg << std::endl;
        #endif
        ++numOfMoves;
    } else {
        /* Choose i = number of remaining pegs. This choice maximizes the
           number of auxiliary pegs we can use during the recursive calls and
           conversely minimizes the number of auxiliary pegs used to store the
           subtowers. Thus, the number of performed moves is the minimum.
           Note that here i is deliberately off by one to compensate for the 1-based
           indexing. */
        int i = numPegs;
        int auxPeg = -1;
        /* Search for the first free auxiliary peg to use. */
        for (int j = numPegs; j > 0; --j) {
            if (occupiedPegs[j] == false) {
                ++numPegs;
                if (auxPeg == -1) auxPeg = j;
            }
        }
        // FIXME: the order needs to be checked.
        moveTower(firstDisk, firstDisk + i, fromPeg, auxPeg);
        occupiedPegs[auxPeg] = true;
        moveTower(firstDisk + i + 1, lastDisk, fromPeg, toPeg);
        occupiedPegs[fromPeg] = false;
        moveTower(firstDisk, firstDisk + i, auxPeg, toPeg);
        occupiedPegs[auxPeg] = false;
    }
}

void initializeFS() {
    for (int d = 1; d <= numDisks; ++d) {
        currentPosition[d] = 1;
    }
    occupiedPegs[1] = true;
    for (int d = 2; d <= numPegs; ++d) {
        occupiedPegs[d] = false;
    }
    numOfMoves = 0;
}

int main() {
    ifstream fin;
    ofstream fout;
    long int fsBestValue = LONG_MAX;

    fin.open("input.txt");
    assert(fin);
    fin >> numDisks;
    fin >> numPegs;
    fin.close();

    initializeFS();
    moveTower(1, numDisks, 1, numPegs);

    fout.open("output.txt"); assert(fout);
    fout << numOfMoves;
    fout.close();
    return 0;
}

