#include <cassert>
#ifdef DEBUG
    #include <iostream>
#endif
#include <fstream>
#include <string>

/* Due to a low stack size, the system I wrote the program on is unable to
   allocate the entire adjacency matrix when we choose 1000000 as N_MAX.
   Increase the constant as necessary, edit the ulimits on your system or edit
   the code to use dynamic memory allocation. */
const long int N_MAX = 200; // FIXME
const long int NODE_NOT_VISITED = -2;
const long int PARENT_OF_ROOT = -1;

int main() {
    using namespace std;

    bool adjMatrix[N_MAX][N_MAX];
    long int parentNode[N_MAX];
    long int children[N_MAX];
    long int visited[N_MAX];
    long int currentNode;
    long int currentParent;
    long int nextIndex;
    long int i;
    long int j;

    /* Initialize the adjacency matrix and the auxiliary arrays. */
    for (i = 0; i < N_MAX; ++i) {
        for (j = 0; j < N_MAX; ++j) {
            adjMatrix[i][j] = false;
        }
        parentNode[i] = NODE_NOT_VISITED;
    }
    ifstream fin("input.txt");
    assert(fin);
    currentNode = 0;
    currentParent = PARENT_OF_ROOT;
    nextIndex = 1;
    do {
        /* If it's the first time we visit this node, set its parent and the
           number of remaining children to be visited. */
        if (parentNode[currentNode] == NODE_NOT_VISITED) {
            parentNode[currentNode] = currentParent;
            fin >> children[currentNode];
            visited[currentNode] = children[currentNode];
            #ifdef DEBUG
                cout << "Parent: " << currentParent << ", children = " << children[currentNode] << endl;
            #endif
        }
        if (visited[currentNode] > 0) {
            /* Visit the visited[currentNode]-th subtree by updating the
               current node and the parent; also track the edge between the
               parent and this child. */
            --visited[currentNode];
            adjMatrix[currentNode][nextIndex] = true;
            currentParent = currentNode;
            currentNode = nextIndex++;
        } else {
            /* We're done exploring the subtree, reset the parent and the current
               node. */
            currentNode = currentParent;
            currentParent = parentNode[currentNode];
            #ifdef DEBUG
                cout << "Return to parent: " << currentNode << endl;
            #endif
        }
    } while (currentNode != PARENT_OF_ROOT);
    fin.close();
    #ifdef DEBUG
        cout << "----------" << endl;
    #endif
    /* The depth-first visit we have done numbers the nodes "from left to right".
       Thus, to obtain the mirrored tree, we just repeat the visit "from right to
       left". */
    ofstream fout("output.txt");
    assert(fout);
    /* Use the "visited" array to keep track of the next index to be swept in the
       matrix. */
    for (i = 0; i < nextIndex - 1; ++i) {
        visited[i] = nextIndex;
    }
    currentNode = 0;
    currentParent = PARENT_OF_ROOT;
    do {
        /* If the node has not been visited, print the number of children. */
        if (visited[currentNode] == nextIndex) {
            --visited[currentNode];
            fout << (currentNode != 0 ? " " : "") << children[currentNode];
            #ifdef DEBUG
                cout << "Children: " << children[currentNode] << endl;
            #endif
        }
        /* Start sweeping from visited[currentNode] and go to the left. */
        if (adjMatrix[currentNode][visited[currentNode]--] == true) {
            currentParent = currentNode;
            currentNode = visited[currentNode] + 1;
            #ifdef DEBUG
                cout << "Moving to " << currentNode << " with parent "
                     << currentParent << endl;
            #endif
        }
        if (visited[currentNode] <= -1) {
            currentNode = currentParent;
            currentParent = parentNode[currentNode];
            #ifdef DEBUG
                cout << "Returning up to " << currentNode << ", "
                     << "parent = " << currentParent << endl;
            #endif
        }
    } while (currentNode != PARENT_OF_ROOT);
    fout.close();
    return 0;
}

